@@ -4,7 +4,7 @@ import os
 import sys
 from .registry import register
 @register("python")
-def build_python_task(task:dict, name):
+def build_python_task(task:dict, name, g=None):
     python_file = task['path']
     args = task.get('args',[])
     kwargs = task.get('kwargs',{})
@@ -14,7 +14,7 @@ def build_python_task(task:dict, name):
         module = import_module(python_file)
         func = getattr(module, func_name)
         task = lambda: func(*args, **kwargs)
-        return Task(task, name)
+        return Task(task, name, g)
     else:
         args = ' '.join([str(x) for x in args])
         kwargs_str = []
