@@ -3,10 +3,12 @@ from .task import build_task
 from .registry import register
 
 @register("task-group")
-def build_task_group(cfg, name, task_spec=None):
+def build_task_group(cfg:dict, name, g=None, task_spec=None):
     '''
     task_spec example: 'train-*,test-*'
     '''
+    if g is None:
+        g = {}
     task_dict = cfg.get('tasks')
     # print(task_dict.keys())
     if isinstance(task_dict, (list, tuple, set)):
@@ -38,6 +40,6 @@ def build_task_group(cfg, name, task_spec=None):
     task_list = []
     for name, t in task_dict.items():
         # print(name)
-        task_list += build_task(t, name)
+        task_list += build_task(t, name, g)
     return task_list
 
