@@ -7,7 +7,7 @@ import ctypes
 import textwrap
 import io
 import os
-from jobx.utils import load_json
+from .utils import load_json,EasyDict
 
 
 class PythonExtension(ext.Extension):
@@ -146,11 +146,12 @@ def load_config_yaml(f, **kwargs):
                                 ], undefined=Undefined).get_template(f,globals=g).render(**kwargs)
         return yaml.safe_load(text)
 
-def load_config(arg_file):
+def load_config(arg_file,**kwargs):
     if arg_file.endswith('.yaml') or arg_file.endswith('.yml'):
-        cfg = load_config_yaml(arg_file)
+        cfg = load_config_yaml(arg_file,**kwargs)
     elif arg_file.endswith('.json'):
         cfg = load_json(arg_file)
     else:
         cfg = load_json(arg_file)
-    return cfg
+
+    return EasyDict(**cfg)
